aboutsummaryrefslogtreecommitdiffstats
path: root/home/pokemon.asm
diff options
context:
space:
mode:
authorSylvie <35663410+Rangi42@users.noreply.github.com>2024-07-24 12:21:59 -0400
committerGitHub <noreply@github.com>2024-07-24 12:21:59 -0400
commit6e3ab0a9e97ff14123ac65f56cb4b4ddab45b695 (patch)
tree32feac5e86fbac9eec6f40c14a19c8bd89c1b52d /home/pokemon.asm
parentIdentify various flag labels and bit constants (#454) (diff)
downloadpokeyellow-6e3ab0a9e97ff14123ac65f56cb4b4ddab45b695.tar.gz
pokeyellow-6e3ab0a9e97ff14123ac65f56cb4b4ddab45b695.tar.xz
pokeyellow-6e3ab0a9e97ff14123ac65f56cb4b4ddab45b695.zip
Identify wcd6d as wNameBuffer and others (#455)
Diffstat (limited to 'home/pokemon.asm')
-rw-r--r--home/pokemon.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/home/pokemon.asm b/home/pokemon.asm
index 131fbd85..b228f086 100644
--- a/home/pokemon.asm
+++ b/home/pokemon.asm
@@ -435,7 +435,7 @@ GetMonHeader::
ld [MBC1RomBank], a
ret
; copy party pokemon's name to wcd6d
GetPartyMonName2::
ld a, [wWhichPokemon] ; index within party
ld hl, wPartyMonNicks
@@ -445,7 +445,7 @@ GetPartyMonName::
push hl
push bc
call SkipFixedLengthTextEntries ; add NAME_LENGTH to hl, a times
- ld de, wcd6d
+ ld de, wNameBuffer
push de
ld bc, NAME_LENGTH
call CopyData
@@ -435,7 +435,7 @@ GetMonHeader::
ld [MBC1RomBank], a
ret
-; copy party pokemon's name to wcd6d
+; copy party pokemon's name to wNameBuffer
GetPartyMonName2::
ld a, [wWhichPokemon] ; index within party